

class CalorieTracker:
    def __init__(self, daily_goal):
        self.daily_goal = daily_goal
        self.calories_consumed = 0

    def add_calories(self, calories):
        """
        Add consumed calories to the tracker.
        """
        self.calories_consumed += calories

    def get_calories_consumed(self):
        """
        Get the total calories consumed.
        """
        return self.calories_consumed

    def compare_to_goal(self):
        """
        Compare total calories consumed to the daily goal.
        Returns:
            -1 if below the goal
            0 if equal to the goal
            1 if above the goal
        """
        if self.calories_consumed < self.daily_goal:
            return -1
        elif self.calories_consumed == self.daily_goal:
            return 0
        else:
            return 1



import setuptools
with open("README.txt", "r", encoding="utf-8") as fh:
    long_description = fh.read()
setuptools.setup(
    name="example-pkg-calorietrackergoal",
    # Replace with your own username above
    version="0.0.1",
    author="Amrutha",
    author_email="x23172151@student.ncirl.ie",
    description="total calorie tracker goal library",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages(),
    # if you have libraries that your module/package/library
    #you would include them in the install_requires argument
    install_requires=[''],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)